@@ -16,8 +16,10 @@ define("address", default='', help="run on the given address", type=str)
 define("debug", default=False, help="run in debug mode", type=bool)
 define("inspect", default=True, help="inspect workers", type=bool)
 define("inspect_timeout", default=1000, type=float,
-        help="inspect timeout (in milliseconds)")
-define("auth", default='', help="comma separated list of emails", type=str)
+       help="inspect timeout (in milliseconds)")
+define("auth", default='', type=str,
+       help="comma separated list of emails to grant access")
+define("url_prefix", type=str, help="base url prefix")
 
 
 class FlowerCommand(Command):
@@ -28,12 +30,17 @@ class FlowerCommand(Command):
         parse_command_line([prog_name] + argv)
         auth = map(str.strip, options.auth.split(',')) if options.auth else []
         app_settings['debug'] = options.debug
+        if options.url_prefix:
+            prefix = options.url_prefix.strip('/')
+            app_settings['static_url_prefix'] = '/{0}/static/'.format(prefix)
+            app_settings['login_url'] = '/{0}/login'.format(prefix)
+            settings.URL_PREFIX = prefix
         settings.CELERY_INSPECT_TIMEOUT = options.inspect_timeout
 
         flower = Flower(celery_app=self.app, auth=auth, **app_settings)
 
         logging.info('Visit me at http://%s:%s' %
-                (options.address or 'localhost', options.port))
+                    (options.address or 'localhost', options.port))
         logging.info('Broker: %s', self.app.connection().as_uri())
         logging.debug('Settings: %s' % pformat(app_settings))
 
