@@ -3,23 +3,32 @@ from __future__ import absolute_import
 import inspect
 import traceback
 
+from urlparse import urljoin
+
 import tornado
 
+from .. import settings
 from ..utils import template
 
 
 class BaseHandler(tornado.web.RequestHandler):
+
+    def prepare(self):
+        self.application.state.resume()
+
     def render(self, *args, **kwargs):
         functions = inspect.getmembers(template, inspect.isfunction)
         assert not set(map(lambda x: x[0], functions)) & set(kwargs.iterkeys())
         kwargs.update(functions)
+        kwargs.update(absolute_url=self.absolute_url)
+        kwargs.update(url_prefix=settings.URL_PREFIX)
         super(BaseHandler, self).render(*args, **kwargs)
 
     def write_error(self, status_code, **kwargs):
         if status_code == 404:
             message = None
             if 'exc_info' in kwargs and\
-                kwargs['exc_info'][0] == tornado.web.HTTPError:
+                    kwargs['exc_info'][0] == tornado.web.HTTPError:
                     message = kwargs['exc_info'][1].log_message
             self.render('404.html', message=message)
         elif status_code == 500:
@@ -33,7 +42,7 @@ class BaseHandler(tornado.web.RequestHandler):
         else:
             message = None
             if 'exc_info' in kwargs and\
-                kwargs['exc_info'][0] == tornado.web.HTTPError:
+                    kwargs['exc_info'][0] == tornado.web.HTTPError:
                     message = kwargs['exc_info'][1].log_message
                     self.set_header('Content-Type', 'text/plain')
                     self.write(message)
@@ -47,3 +56,11 @@ class BaseHandler(tornado.web.RequestHandler):
             return user
         else:
             return None
+
+    def absolute_url(self, url):
+        base = "{0}://{1}/".format(self.request.protocol, self.request.host)
+        if settings.URL_PREFIX:
+            base += settings.URL_PREFIX + '/'
+        aurl = urljoin(base, url[1:] if url.startswith('/') else url)
+        aurl = aurl[:-1] if aurl.endswith('/') else aurl
+        return aurl
